==> jc-1.4.0.tar.gz: javax/swing/colorchooser/DefaultColorSelectionModel.h <==
// public class javax.swing.colorchooser.DefaultColorSelectionModel

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c675c82a8deb2a77 javax_swing_colorchooser_DefaultColorSelectionModel

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_colorchooser_DefaultColorSelectionModel_H_
#define _JC_javax_swing_colorchooser_DefaultColorSelectionModel_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_event_ChangeEvent$object;
struct _jc_javax_swing_event_ChangeListener$object;
struct _jc_javax_swing_event_EventListenerList$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$sub_refs	_jc_javax_swing_colorchooser_DefaultColorSelectionModel$sub_refs;
typedef struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$sub_nonrefs	_jc_javax_swing_colorchooser_DefaultColorSelectionModel$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$refs	_jc_javax_swing_colorchooser_DefaultColorSelectionModel$refs;
typedef struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$nonrefs	_jc_javax_swing_colorchooser_DefaultColorSelectionModel$nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object	_jc_javax_swing_colorchooser_DefaultColorSelectionModel$object;

typedef struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$fields_struct	_jc_javax_swing_colorchooser_DefaultColorSelectionModel$fields_struct;
typedef const struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$vmethods	_jc_javax_swing_colorchooser_DefaultColorSelectionModel$vmethods;
typedef const struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$vtable	_jc_javax_swing_colorchooser_DefaultColorSelectionModel$vtable;
typedef const struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$vtype	_jc_javax_swing_colorchooser_DefaultColorSelectionModel$vtype;

// Class fields structure
struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24swing__24event__24ChangeListener;
	jlong	serialVersionUID;
};
extern _jc_javax_swing_colorchooser_DefaultColorSelectionModel$fields_struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$class_fields;

// Constructors
extern void _jc_javax_swing_colorchooser_DefaultColorSelectionModel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *);
extern void _jc_javax_swing_colorchooser_DefaultColorSelectionModel$method$_init$d42470fc2dba686a(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *, struct _jc_java_awt_Color$object *);

// Virtual methods
extern void _jc_javax_swing_colorchooser_DefaultColorSelectionModel$method$addChangeListener$1fcb1bdc58c7c6d8(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *, struct _jc_object *);
extern void _jc_javax_swing_colorchooser_DefaultColorSelectionModel$method$fireStateChanged$6a2faae97d997d9a(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *);
extern _jc_object_array *_jc_javax_swing_colorchooser_DefaultColorSelectionModel$method$getChangeListeners$9dde76dbf9f557be(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *);
extern struct _jc_java_awt_Color$object *_jc_javax_swing_colorchooser_DefaultColorSelectionModel$method$getSelectedColor$36079cfb8ca5079f(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *);
extern void _jc_javax_swing_colorchooser_DefaultColorSelectionModel$method$removeChangeListener$91e6a7f8d24a5df2(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *, struct _jc_object *);
extern void _jc_javax_swing_colorchooser_DefaultColorSelectionModel$method$setSelectedColor$b0ee5fc9635db9ae(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *, struct _jc_java_awt_Color$object *);
extern void _jc_javax_swing_colorchooser_DefaultColorSelectionModel$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_DefaultColorSelectionModel$method_info$addChangeListener$1fcb1bdc58c7c6d8;
extern _jc_method _jc_javax_swing_colorchooser_DefaultColorSelectionModel$method_info$fireStateChanged$6a2faae97d997d9a;
extern _jc_method _jc_javax_swing_colorchooser_DefaultColorSelectionModel$method_info$getChangeListeners$9dde76dbf9f557be;
extern _jc_method _jc_javax_swing_colorchooser_DefaultColorSelectionModel$method_info$getSelectedColor$36079cfb8ca5079f;
extern _jc_method _jc_javax_swing_colorchooser_DefaultColorSelectionModel$method_info$removeChangeListener$91e6a7f8d24a5df2;
extern _jc_method _jc_javax_swing_colorchooser_DefaultColorSelectionModel$method_info$setSelectedColor$b0ee5fc9635db9ae;
extern _jc_method _jc_javax_swing_colorchooser_DefaultColorSelectionModel$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_swing_colorchooser_DefaultColorSelectionModel$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$vmethods {
	void	(*addChangeListener$1fcb1bdc58c7c6d8)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *, struct _jc_object *);
	void	(*fireStateChanged$6a2faae97d997d9a)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *);
	_jc_object_array	*(*getChangeListeners$9dde76dbf9f557be)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *);
	struct _jc_java_awt_Color$object	*(*getSelectedColor$36079cfb8ca5079f)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *);
	void	(*removeChangeListener$91e6a7f8d24a5df2)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *, struct _jc_object *);
	void	(*setSelectedColor$b0ee5fc9635db9ae)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *, struct _jc_java_awt_Color$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *);
};

// Vtable
struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_colorchooser_DefaultColorSelectionModel$vmethods	javax_swing_colorchooser_DefaultColorSelectionModel;
};

// Vtype
struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_DefaultColorSelectionModel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$sub_refs {
	struct _jc_java_awt_Color$object	*selectedColor;
	struct _jc_javax_swing_event_ChangeEvent$object	*changeEvent;
	struct _jc_javax_swing_event_EventListenerList$object	*listenerList;
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$refs {
    _jc_javax_swing_colorchooser_DefaultColorSelectionModel$sub_refs	javax_swing_colorchooser_DefaultColorSelectionModel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_colorchooser_DefaultColorSelectionModel$sub_nonrefs	javax_swing_colorchooser_DefaultColorSelectionModel;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object {
	_jc_javax_swing_colorchooser_DefaultColorSelectionModel$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_DefaultColorSelectionModel$vtype	*vtype;
	_jc_javax_swing_colorchooser_DefaultColorSelectionModel$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_DefaultColorSelectionModel$vtype _jc_javax_swing_colorchooser_DefaultColorSelectionModel$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_DefaultColorSelectionModel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_DefaultColorSelectionModel$class_object;

#endif	/* _JC_javax_swing_colorchooser_DefaultColorSelectionModel_H_ */

==> jc-1.4.6.tar.gz: javax/swing/colorchooser/DefaultColorSelectionModel.h <==
// public class javax.swing.colorchooser.DefaultColorSelectionModel

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c675c82a8deb2a77 javax_swing_colorchooser_DefaultColorSelectionModel

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_colorchooser_DefaultColorSelectionModel_H_
#define _JC_javax_swing_colorchooser_DefaultColorSelectionModel_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_event_ChangeEvent$object;
struct _jc_javax_swing_event_ChangeListener$object;
struct _jc_javax_swing_event_EventListenerList$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$sub_refs	_jc_javax_swing_colorchooser_DefaultColorSelectionModel$sub_refs;
typedef struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$sub_nonrefs	_jc_javax_swing_colorchooser_DefaultColorSelectionModel$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$refs	_jc_javax_swing_colorchooser_DefaultColorSelectionModel$refs;
typedef struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$nonrefs	_jc_javax_swing_colorchooser_DefaultColorSelectionModel$nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object	_jc_javax_swing_colorchooser_DefaultColorSelectionModel$object;

typedef struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$fields_struct	_jc_javax_swing_colorchooser_DefaultColorSelectionModel$fields_struct;
typedef const struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$vmethods	_jc_javax_swing_colorchooser_DefaultColorSelectionModel$vmethods;
typedef const struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$vtable	_jc_javax_swing_colorchooser_DefaultColorSelectionModel$vtable;
typedef const struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$vtype	_jc_javax_swing_colorchooser_DefaultColorSelectionModel$vtype;

// Class fields structure
struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24swing__24event__24ChangeListener;
	jlong	serialVersionUID;
};
extern _jc_javax_swing_colorchooser_DefaultColorSelectionModel$fields_struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$class_fields;

// Constructors
extern void _jc_javax_swing_colorchooser_DefaultColorSelectionModel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultColorSelectionModel$method$_init$d42470fc2dba686a(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *, struct _jc_java_awt_Color$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_colorchooser_DefaultColorSelectionModel$method$addChangeListener$1fcb1bdc58c7c6d8(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultColorSelectionModel$method$fireStateChanged$6a2faae97d997d9a(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_javax_swing_colorchooser_DefaultColorSelectionModel$method$getChangeListeners$9dde76dbf9f557be(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Color$object *_jc_javax_swing_colorchooser_DefaultColorSelectionModel$method$getSelectedColor$36079cfb8ca5079f(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultColorSelectionModel$method$removeChangeListener$91e6a7f8d24a5df2(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultColorSelectionModel$method$setSelectedColor$b0ee5fc9635db9ae(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *, struct _jc_java_awt_Color$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultColorSelectionModel$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_DefaultColorSelectionModel$method_info$addChangeListener$1fcb1bdc58c7c6d8;
extern _jc_method _jc_javax_swing_colorchooser_DefaultColorSelectionModel$method_info$fireStateChanged$6a2faae97d997d9a;
extern _jc_method _jc_javax_swing_colorchooser_DefaultColorSelectionModel$method_info$getChangeListeners$9dde76dbf9f557be;
extern _jc_method _jc_javax_swing_colorchooser_DefaultColorSelectionModel$method_info$getSelectedColor$36079cfb8ca5079f;
extern _jc_method _jc_javax_swing_colorchooser_DefaultColorSelectionModel$method_info$removeChangeListener$91e6a7f8d24a5df2;
extern _jc_method _jc_javax_swing_colorchooser_DefaultColorSelectionModel$method_info$setSelectedColor$b0ee5fc9635db9ae;
extern _jc_method _jc_javax_swing_colorchooser_DefaultColorSelectionModel$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_swing_colorchooser_DefaultColorSelectionModel$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$vmethods {
	void	(*addChangeListener$1fcb1bdc58c7c6d8)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*fireStateChanged$6a2faae97d997d9a)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getChangeListeners$9dde76dbf9f557be)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Color$object	*(*getSelectedColor$36079cfb8ca5079f)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *) _JC_JCNI_ATTR;
	void	(*removeChangeListener$91e6a7f8d24a5df2)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*setSelectedColor$b0ee5fc9635db9ae)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *, struct _jc_java_awt_Color$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_colorchooser_DefaultColorSelectionModel$vmethods	javax_swing_colorchooser_DefaultColorSelectionModel;
};

// Vtype
struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_DefaultColorSelectionModel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$sub_refs {
	struct _jc_java_awt_Color$object	*selectedColor;
	struct _jc_javax_swing_event_ChangeEvent$object	*changeEvent;
	struct _jc_javax_swing_event_EventListenerList$object	*listenerList;
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$refs {
    _jc_javax_swing_colorchooser_DefaultColorSelectionModel$sub_refs	javax_swing_colorchooser_DefaultColorSelectionModel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_colorchooser_DefaultColorSelectionModel$sub_nonrefs	javax_swing_colorchooser_DefaultColorSelectionModel;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_DefaultColorSelectionModel$object {
	_jc_javax_swing_colorchooser_DefaultColorSelectionModel$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_DefaultColorSelectionModel$vtype	*vtype;
	_jc_javax_swing_colorchooser_DefaultColorSelectionModel$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_DefaultColorSelectionModel$vtype _jc_javax_swing_colorchooser_DefaultColorSelectionModel$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_DefaultColorSelectionModel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_DefaultColorSelectionModel$class_object;

#endif	/* _JC_javax_swing_colorchooser_DefaultColorSelectionModel_H_ */
